from distutils.core import setup

setup(
    name = 'su_nester',
    version = '1.0.0',
    py_modules = ['nester'],
    author = 'sujunyi',
    author_email = 'sujunyi_test@163.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested list',
)
